@@ -86,7 +86,7 @@ sub GetPageHeader ()
   }
   else
   {
-    return new DiskStruct( "LLLSSSS", [ qw(lsn1 lsn2 sui lower upper special opaque) ] );
+    return new DiskStruct( "LLLSSSCC", [ qw(lsn1 lsn2 sui lower upper special version pagesize) ] );
   }
 }
 
@@ -99,12 +99,29 @@ sub GetPGAttribute ()
                            attnelems attcacheoff atttypmod  attbyval attisset attalign  
                            attnotnull atthasdef) ] );
   }
-  else
+  elsif( $version < 73 )  # 7.3 increase length of name type
   {
     return new DiskStruct( "LA32Ll ss lll CACA CC", [ qw(attrelid attname atttypid attstattarget  attlen attnum  
                            attndim attcacheoff atttypmod  attbyval attstorage attisset attalign  
                            attnotnull atthasdef) ] );
   }
+  else
+  {
+    return new DiskStruct( "LA64Ll ss lll CACA CC", [ qw(attrelid attname atttypid attstattarget  attlen attnum  
+                           attndim attcacheoff atttypmod  attbyval attstorage attisset attalign  
+                           attnotnull atthasdef) ] );
+  }
 }
 
+sub GetTupleHeader ()
+{
+  if( $version < 73 )   # 7.3 completely changed the header
+  {
+    return new DiskStruct( "LLLLLSSSSSC", [ qw( oid cmin cmax xmin xmax tid1 tid2 tid3 natts infomask size ) ] );
+  }
+  else
+  {
+    return new DiskStruct( "LLLSSSSSC", [ qw( xmin xmax xvac tid1 tid2 tid3 natts infomask size ) ] );
+  }
+}
 1;
